@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "contactcompletionmodel_p.h"
@@ -38,16 +25,16 @@ QAbstractItemModel *ContactCompletionModel::self()
         return mSelf;
     }
 
-    Monitor *monitor = new Monitor;
+    auto *monitor = new Monitor;
     monitor->setObjectName(QStringLiteral("ContactCompletionModelMonitor"));
     monitor->fetchCollection(true);
     monitor->itemFetchScope().fetchFullPayload();
     monitor->setCollectionMonitored(Akonadi::Collection::root());
     monitor->setMimeTypeMonitored(KContacts::Addressee::mimeType());
 
-    ContactCompletionModel *model = new ContactCompletionModel(monitor);
+    auto *model = new ContactCompletionModel(monitor);
 
-    EntityMimeTypeFilterModel *filter = new Akonadi::EntityMimeTypeFilterModel(model);
+    auto *filter = new Akonadi::EntityMimeTypeFilterModel(model);
     filter->setSourceModel(model);
     filter->addMimeTypeExclusionFilter(Akonadi::Collection::mimeType());
     filter->addMimeTypeExclusionFilter(Akonadi::Collection::virtualMimeType());
