@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "contactviewerdialog.h"
@@ -39,7 +26,6 @@ class Q_DECL_HIDDEN ContactViewerDialog::Private
 public:
     Private(ContactViewerDialog *parent)
         : q(parent)
-        , mViewer(nullptr)
     {
     }
 
@@ -61,7 +47,7 @@ public:
         group.sync();
     }
 
-    ContactViewerDialog *q = nullptr;
+    ContactViewerDialog *const q;
     ContactViewer *mViewer = nullptr;
 };
 
@@ -70,7 +56,7 @@ ContactViewerDialog::ContactViewerDialog(QWidget *parent)
     , d(new Private(this))
 {
     setWindowTitle(i18nc("@title:window", "Show Contact"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok, this);
     QWidget *mainWidget = new QWidget(this);
@@ -81,12 +67,12 @@ ContactViewerDialog::ContactViewerDialog(QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::accepted, this, &ContactViewerDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ContactViewerDialog::reject);
 
-    QVBoxLayout *layout = new QVBoxLayout(mainWidget);
+    auto *layout = new QVBoxLayout(mainWidget);
 
     d->mViewer = new ContactViewer(this);
     layout->addWidget(d->mViewer);
 
-    ContactDefaultActions *actions = new ContactDefaultActions(this);
+    auto *actions = new ContactDefaultActions(this);
     actions->connectToView(d->mViewer);
 
     mainLayout->addWidget(buttonBox);
