@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
@@ -29,6 +16,7 @@
 #include <QContextMenuEvent>
 #include <QMenu>
 #include <QClipboard>
+#include <QRegularExpression>
 #include <QTextBlock>
 
 using namespace Akonadi;
@@ -81,7 +69,7 @@ void TextBrowser::contextMenuEvent(QContextMenuEvent *event)
             // no point in copying these.  Internal links are always in the
             // form "protocol:?argument", whereas valid external links should
             // be in the form starting with "protocol://".
-            if (!link.contains(QRegExp(QStringLiteral("^\\w+:\\?")))) {
+            if (!link.contains(QRegularExpression(QStringLiteral("^\\w+:\\?")))) {
                 mDataToCopy = link;
                 // Action text matches that used in Konqueror
                 act->setText(i18nc("@action:inmenu Copy a link URL", "Copy Link URL"));
@@ -101,12 +89,12 @@ void TextBrowser::contextMenuEvent(QContextMenuEvent *event)
             if (text.startsWith(QChar(0xFFFC))) {
                 QTextCharFormat charFormat = curs.charFormat();
                 if (charFormat.isImageFormat()) {
-                    QTextImageFormat imageFormat = charFormat.toImageFormat();
-                    QString imageName = imageFormat.name();
-                    QVariant imageResource = document()->resource(QTextDocument::ImageResource,
+                    const QTextImageFormat imageFormat = charFormat.toImageFormat();
+                    const QString imageName = imageFormat.name();
+                    const QVariant imageResource = document()->resource(QTextDocument::ImageResource,
                                                                   QUrl(imageName));
 
-                    QPixmap pix = imageResource.value<QPixmap>();
+                    const QPixmap pix = imageResource.value<QPixmap>();
                     if (!pix.isNull()) {
                         // There may be other images (e.g. contact type icons) that
                         // there is no point in copying.
@@ -124,7 +112,7 @@ void TextBrowser::contextMenuEvent(QContextMenuEvent *event)
                 // telephone number.  See
                 // kdepim/kaddressbook/grantlee/grantleecontactformatter.cpp and
                 // kdepimlibs/akonadi/contact/standardcontactformatter.cpp
-                text.remove(QRegExp(QStringLiteral("\\s*\\(SMS\\)$")));
+                text.remove(QRegularExpression(QStringLiteral("\\s*\\(SMS\\)$")));
 
                 // For an item which was formatted with line breaks (as <br>
                 // in HTML), the returned text contains the character 0x2028
