@@ -1,22 +1,9 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "contacteditorwidget.h"
@@ -46,7 +33,6 @@ public:
     Private(ContactEditorWidget::DisplayMode displayMode, ContactEditorWidget *parent)
         : mDisplayMode(displayMode)
         , mParent(parent)
-        , mCustomFieldsWidget(nullptr)
     {
     }
 
@@ -64,7 +50,7 @@ public:
     void storeCustom(KContacts::Addressee &contact, const QString &key, const QString &value) const;
 
     ContactEditorWidget::DisplayMode mDisplayMode;
-    ContactEditorWidget *mParent = nullptr;
+    ContactEditorWidget *const mParent;
     QTabWidget *mTabWidget = nullptr;
 
     ContactEditor::GeneralInfoWidget *mGeneralInfoWidget = nullptr;
@@ -88,7 +74,7 @@ public:
 
 void ContactEditorWidget::Private::initGui()
 {
-    QVBoxLayout *layout = new QVBoxLayout(mParent);
+    auto *layout = new QVBoxLayout(mParent);
     layout->setContentsMargins(0, 0, 0, 0);
 
     mTabWidget = new QTabWidget(mParent);
@@ -132,7 +118,7 @@ void ContactEditorWidget::Private::initGuiPersonalTab()
 void ContactEditorWidget::Private::initGuiNotesTab()
 {
     QWidget *widget = new QWidget;
-    QVBoxLayout *layout = new QVBoxLayout(widget);
+    auto *layout = new QVBoxLayout(widget);
 
     mTabWidget->addTab(widget, i18nc("@title:tab", "Notes"));
 
